***GETTING STARTED***

get FILE="U:\Public Health SPSS\Good stuff\Diabetes\Diabetes.sav".

FREQUENCIES chol
/histogram normal.


*DESCRIPTIVES VARIABLES=ratio
  /STATISTICS=MEAN STDDEV MIN MAX KURTOSIS SKEWNESS.*


***PRELIMINARY TRANSFORMATIONS***


DESCRIPTIVES ratio.

VARIABLE LABELS ratio 'Cholesterol/HDL Ratio'.
DESCRIPTIVES ratio.

VARIABLE LABELS
id 'Subject ID'
chol 'Total Cholesterol'
stab.glu 'Stabilized Glucose'
hdl 'High Density Lipoprotein'
glyhb 'Glycosylated Hemoglobin'.

*****vvv*****CHALLENGE 1 - PUT YOUR SYNTAX HERE*****vvv*****

VARIABLE LABELS
bp.1s 'First Systolic Blood Pressure'
bp.1d 'First Diastolic Blood Pressure'
bp.2s 'Second Systolic Blood Pressure'
bp.2d 'Second Diastolic Blood Pressure'
time.ppn 'Postprandial Time when Labs were Drawn'.

*****^^^*****CHALLENGE 1 - PUT YOUR SYNTAX HERE*****^^^*****

FREQUENCIES chol
/histogram normal.


*****vvv*****CHALLENGE 2 - PUT YOUR SYNTAX HERE*****vvv*****

FREQUENCIES frame
/histogram normal.

*****^^^*****CHALLENGE 2 - PUT YOUR SYNTAX HERE*****^^^*****

DESCRIPTIVES chol
/STATISTICS MEAN MIN MAX STDDEV SKEWNESS KURTOSIS.

MEANS chol by location
/STATISTICS.

FREQUENCIES weight
/HISTOGRAM normal.

DESCRIPTIVES weight
/STATISTICS mean stddev skewness kurtosis
/SAVE.

CROSSTABS gender by location
/STATISTICS=CHISQ
/BARCHART.

*****vvv*****CHALLENGE 3 - PUT YOUR SYNTAX HERE*****vvv*****

FREQUENCIES glyhb.

DESCRIPTIVES bp.1s bp.1d.

MEANS glyhb by frame.

CROSSTABS gender by frame.

*****^^^*****CHALLENGE 3 - PUT YOUR SYNTAX HERE*****^^^*****


* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=age glyhb MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: age=col(source(s), name("age"))
  DATA: glyhb=col(source(s), name("glyhb"))
  GUIDE: axis(dim(1), label("age"))
  GUIDE: axis(dim(2), label("Glycosolated Hemoglobin"))
  GUIDE: text.title(label("Glycosolated Hemoglobin by Age"))
  ELEMENT: point(position(age*glyhb))
END GPL.

CORRELATIONS glyhb age.

REGRESSION 
/DEPENDENT glyhb
/METHOD=ENTER age
/DESCRIPTIVES MEAN STDDEV CORR SIG N.


***EXTRA SECTION 1*** You may skip this if you like***

GRAPH
  /SCATTERPLOT(BIVAR)=age WITH glyhb
  /TITLE='Glycosolated Hemoglobin by Age'.

***DATA TRANSFORMATIONS: RECODING VARIABLES, ASSIGNING NEW VALUES, AND COMPUTATION***

FREQUENCIES frame
/format notable
/histogram normal.

RECODE frame ('small'=1)('medium'=2)('large'=3)(""=999) INTO frame_code.
MISSING VALUES frame_code(999).
VARIABLE LEVEL frame_code(Ordinal).
EXECUTE.

VALUE LABELS frame_code 1 Small  2 'Medium' 3 'Large'  999 Missing.

FORMATS frame_code(F1.0).

RECODE frame_code (1=3) (2=2)(3=1)(ELSE=COPY) INTO frame_code2.
MISSING VALUES frame_code2(999).
VARIABLE LEVEL frame_code2(Ordinal).
FORMATS frame_code2(F1.0).
EXECUTE.


*****vvv*****CHALLENGE 4 - PUT YOUR SYNTAX HERE*****vvv*****

VALUE LABELS frame_code 1 'Large'  2 'Medium' 3 'Small'  999 Missing.

*****^^^*****CHALLENGE 4 - PUT YOUR SYNTAX HERE*****^^^*****

DELETE VARIABLES frame_code2.

SORT CASES location.
AUTORECODE location
/INTO loc_code
/GROUP
/PRINT.

FREQUENCIES location
/histogram normal.

IF (frame='small')  frame_code3=1.
IF (frame='medium') frame_code3=2.
IF (frame='large') frame_code3=3.
IF (frame="") frame_code3=999.
MISSING VALUES frame_code(999).
VARIABLE LEVEL frame_code (Ordinal).
EXECUTE.

*****vvv*****CHALLENGE 5 - PUT YOUR SYNTAX HERE*****vvv*****

DELETE VARIABLES frame_code3.

*****^^^*****CHALLENGE 5 - PUT YOUR SYNTAX HERE*****^^^*****

RECODE chol (LOWEST THRU 200 = 0)(200 THRU 220 = 1)(220 THRU 240=2)(241 THRU HIGHEST = 3)(ELSE = 999) INTO total_chol.
MISSING VALUES total_chol(999).
VARIABLE LEVEL total_chol(Scale).
FORMATS total_chol(f1.0).
EXECUTE.

VARIABLE LABELS total_chol 'Total Cholesterol Score Rank'.

VALUE LABELS total_chol
0 "Optimal"
1 "Borderline High"
2 "High"
3 "Very High".


COMPUTE Height_ft=(height/12).

IF missing(height) Height_ft=999.
MISSING VALUES Height_ft(999).
EXECUTE.

*****vvv*****CHALLENGE 6 - PUT YOUR SYNTAX HERE*****vvv*****

SORT CASES Height_ft.

*****^^^*****CHALLENGE 6 - PUT YOUR SYNTAX HERE*****^^^*****


*****vvv*****CHALLENGE 7 - PUT YOUR SYNTAX HERE*****vvv*****

COMPUTE BMI=(703*weight/(height**2)).
IF missiing(height) or missing(weight) BMI=999.
MISSING VALUES BMI(999).
EXECUTE.

*****^^^*****CHALLENGE 7 - PUT YOUR SYNTAX HERE*****^^^*****


COMPUTE WH_Ratio=(waist/hip).
VARIABLE LABELS WH_Ratio 'Wasit-Hip Ratio'.


*****vvv*****CHALLENGE 8 - PUT YOUR SYNTAX HERE*****vvv*****

SORT CASES WH_Ratio.

*****^^^*****CHALLENGE 8 - PUT YOUR SYNTAX HERE*****^^^*****


IF missing(waist) or missing(hip) WH_Ratio=999.
MISSING VALUES WH_Ratio(999).
EXECUTE.

IF (glyhb<5.6) T2D=0.
IF (glyhb>=5.6 and glyhb<7) T2D=1.
IF (glyhb>=7)T2D=2.
VARIABLE LABELS T2D 'Type II Diabetes'.
VALUE LABELS T2D 0 'Not Diabetic' 1 'Pre-Diabetic' 2 'DIabetic'.

IF (gender='male' and WH_Ratio<=0.95) WH_Risk=0.
IF (gender='male' and (WH_Ratio>0.95 and WH_Ratio<1)) WH_Risk=1.
IF (gender='male' and (WH_Ratio>=1)) WH_Risk=2.



*****vvv*****CHALLENGE 9 - PUT YOUR SYNTAX HERE*****vvv*****

IF (gender='female' and (WH_Ratio<=0.80)) WH_Risk=0.
IF (gender='female' and (WH_Ratio>0.80 and WH_Ratio<0.86)) WH_Risk=1.
IF (gender='female' and (WH_Ratio>=0.86)) WH_Risk=2.
IF missing(WH_Risk) WH_Risk=999.
MISSING VALUES WH_Risk (999).
VARIABLE LABELS WH_Risk 'Waist-to-Hip Ratio Scale'.
VALUE LABELS WH_Risk 0 'Low' 1 'Moderate' 2 'High'.
VARIABLE LEVEL WH_Risk(Ordinal).
FORMATS WH_Risk (F1.0).
FREQUENCIES WH_Risk.


FREQUENCIES WH_Risk.



*****^^^*****CHALLENGE 9 - PUT YOUR SYNTAX HERE*****^^^*****



DO IF gender='male'.
IF (WH_Ratio<=0.95) WH_Risk2=0.
IF (WH_Ratio>0.95 and WH_Ratio<1) WH_Risk2=1.
IF (WH_Ratio>=1) WH_Risk2=2.
ELSE IF gender ='female'.
IF (WH_Ratio<=0.80) WH_Risk2=0.	
IF  (WH_Ratio>0.80 and WH_Ratio<0.86) WH_Risk2=1.
IF (WH_Ratio>=0.86) WH_Risk2=2.
END IF.
IF missing(WH_Risk2) WH_Risk2=999.
MISSING VALUES WH_Risk2(999).
EXECUTE.

frequencies WH_Risk WH_Risk2.


DESCRIPTIVES bp.1s bp.1d.

IF ((bp.1s <= 120) and (bp.1d <= 80)) BP_Risk=0.
IF ((bp.1s > 120) and (bp.1s <=129)) and bp.1d <80 BP_Risk=1.
IF ((bp.1s >= 130 and bp.1s <= 139) or (bp.1d >= 80 and bp.1d <= 89)) BP_Risk=2.
IF (bp.1s > 140 and bp.1s <= 180) or (bp.1d > 90 and bp.1d <= 120) BP_Risk=3.
IF (bp.1s > 180 and bp.1d > 90) BP_Risk=4.

VARIABLE LEVEL BP_Risk(Ordinal).
FREQUENCIES BP_Risk.


*****vvv*****CHALLENGE 10 - PUT YOUR SYNTAX HERE*****vvv*****

IF (bp.1s <= 90) Sys_Code = -1.
IF ((bp.1s > 90) and (bp.1s <=120)) Sys_Code = 0.
IF ((bp.1s > 120) and (bp.1s <=129)) Sys_Code = 1.
IF((bp.1s >= 130) and (bp.1s <=139)) Sys_Code = 2.
IF((bp.1s >= 140) and (bp.1s <=180)) Sys_Code = 3.
IF (bp.1s > 180) Sys_Code = 4.
Execute.
FREQUENCIES Sys_Code.

IF (bp.1d <= 60) Dia_Code = -1.
IF ((bp.1d > 60) and (bp.1d <=80)) Dia_Code = 0.
IF ((bp.1d > 80) and (bp.1d <90)) Dia_Code = 1.
IF((bp.1d >= 90) and (bp.1d <=120)) Dia_Code = 2.
IF(bp.1d > 120) Dia_Code = 3.
EXECUTE.
FREQUENCIES Dia_Code.

*****^^^*****CHALLENGE 10 - PUT YOUR SYNTAX HERE*****^^^*****


IF ((Sys_Code = -1) and (Dia_Code = -1)) BP_Class = -1.
IF ((Sys_Code = 0) and (Dia_Code = 0)) BP_Class = 0.
IF ((Sys_Code = 1) and (Dia_Code = 0)) BP_Class = 1.
IF ((Sys_Code = 2) or (Dia_Code = 1)) BP_Class = 2.
IF ((Sys_Code = 1) or (Sys_Code = 2)) and (Dia_Code = 0) BP_Class = 3.
IF ((Sys_Code = 3) or (Dia_Code = 1)) BP_Class = 4.
IF ((Sys_Code = 3) or (Dia_Code = 2)) BP_Class = 5.
IF ((Sys_Code = 4) or (Dia_Code = 3)) BP_Class = 6.
EXECUTE.
FREQUENCIES BP_Class.


*****vvv*****CHALLENGE 11 - PUT YOUR SYNTAX HERE*****vvv*****

IF missing(BP_Class) BP_Class=999.
MISSING VALUES BP_Class(999).
EXECUTE.

*****^^^*****CHALLENGE 11 - PUT YOUR SYNTAX HERE*****^^^*****


SORT CASES BP_Class.
SPLIT FILE BP_Class.
DESCRIPTIVES bp.1s bp.1d.

SPLIT FILE off.

IF ((Sys_Code = -1) and (Dia_Code = -1)) BP_Class = -2.
IF ((Sys_Code = 0) and (Dia_Code = -1)) BP_Class = -1.
IF ((Sys_Code = 0) and (Dia_Code = 0)) BP_Class = 0.
IF ((Sys_Code = 1) and (Dia_Code = 0)) BP_Class = 1.
IF ((Sys_Code = 2) or (Dia_Code = 1)) BP_Class = 2.
IF ((Sys_Code = 1) or (Sys_Code = 2)) and (Dia_Code = 0) BP_Class = 3.
IF ((Sys_Code = 3) or (Dia_Code = 1)) BP_Class = 4.
IF ((Sys_Code = 3) or (Dia_Code = 2)) BP_Class = 5.
IF ((Sys_Code = 4) or (Dia_Code = 3)) BP_Class = 6.
EXECUTE.
FREQUENCIES BP_Class.



*****vvv*****CHALLENGE 12 - PUT YOUR SYNTAX HERE*****vvv*****

VARIABLE LABELS BP_Class 'Blood Pressure Risk Category'.

VALUE LABELS BP_Class
-2	'Low blood pressure'
-1	'Isolated Diastolic Hypotension'
0	'Healthy Range'
1	'Prehypertension'
2	'Stage 1 Hypertension'
3	'Pre-ISH'
4	'Isolated Systolic Hypertension'
5	'Stage 2 Hypertension'
6	'Hypertensive Crisis'.

FORMATS BP_Class(F1.0).

VARIABLE LEVEL BP_Class(ORDINAL).

*****^^^*****CHALLENGE 12 - PUT YOUR SYNTAX HERE*****^^^*****



*****vvv*****CHALLENGE 13 - PUT YOUR SYNTAX HERE*****vvv*****

RECODE hdl (LOWEST THRU 39 = 0)(40 THRU 60 = 1)(61 THRU HIGHEST = 2)(ELSE = 999) INTO HDL_Code.
VARIABLE LABELS HDL_Code 'High-Density Lipoprotein Score'.
VALUE LABELS HDL_Code 0 'High Risk' 1 'Lower Risk' 2 'Optimal'.
MISSING VALUES HDL_Code(999).
VARIABLE LEVEL HDL_Code(Ordinal).
FORMATS HDL_Code (F1.0).
EXECUTE.


*****^^^*****CHALLENGE 13 - PUT YOUR SYNTAX HERE*****^^^*****



*****vvv*****CHALLENGE 14 - PUT YOUR SYNTAX HERE*****vvv*****

COMPUTE non_hdl=chol-hdl.
EXECUTE.

RECODE non_hdl (LOWEST THRU 129 = 0)(130 THRU 159 = 1)(160 THRU 189 = 2)(190 THRU HIGHEST =3)(ELSE = 999 ) INTO non_hdl_code.
MISSING VALUES non_hdl_code(999).
VARIABLE LABELS non_hdl_code 'Non-HDL Cholesterol Risk Level'.
VALUE LABELS non_hdl_code 0 'Optimal' 1 'Borderline High' 2 'High' 3 'Very High'.
VARIABLE LEVEL non_hdl_code(Ordinal).
FORMATS non_hdl_code (F1.0).
EXECUTE.


*****^^^*****CHALLENGE 14 - PUT YOUR SYNTAX HERE*****^^^*****


*****vvv*****CHALLENGE 15 - PUT YOUR SYNTAX HERE*****vvv*****

DO IF gender='female'.
IF (Ratio<3) TCR_Scale=0.
IF (Ratio>=3) and (Ratio <=4.4) TCR_Scale=1.
IF (Ratio>4.4) TCR_Scale=2.
ELSE IF gender='male'.
IF (Ratio<3.5) TCR_Scale=0.
IF (Ratio>=3.5) and (Ratio <=5) TCR_Scale=1.
IF (Ratio>5) TCR_Scale=2.
END IF.
IF missing(TCR_Scale) TCR_Scale=999.
MISSING VALUES TCR_Scale(999).
VARIABLE LEVEL TCR_Scale(Ordinal).
VARIABLE LABELS TCR_Scale 'Total Cholesterol Ratio Scale'.
VALUE LABELS TCR_Scale 0 'Optimal' 1 'Moderate' 2 'High'.
FORMATS TCR_Scale(F1.0).
EXECUTE.


*****^^^*****CHALLENGE 15 - PUT YOUR SYNTAX HERE*****^^^*****


IF ((bp.1s <= 120) and (bp.1d <= 80)) BP_Risk=0.
IF ((bp.1s > 120) and (bp.1s <=129)) and bp.1d <80 BP_Risk=1.
IF ((bp.1s >= 130 and bp.1s <= 139) or (bp.1d >= 80 and bp.1d <= 89)) BP_Risk=2.
IF (bp.1s > 140 and bp.1s <= 180) or (bp.1d > 90 and bp.1d <= 120) BP_Risk=3.
IF (bp.1s > 180 and bp.1d > 90) BP_Risk=4.
IF Missing(BP_Risk) BP_Risk=999.
MISSING VALUES BP_Risk(999).
VARIABLE LEVEL BP_Risk(Ordinal).
FREQUENCIES BP_Risk.

MEANS WH_Ratio by BP_Risk
/STATISTICS ANOVA.

CROSSTABS WH_Risk by BP_Risk
/STATISTICS CHISQ.

Means bp.1s bp.2s by WH_Risk
/statistics anova.

means glyhb by WH_Risk
/statistics anova.

crosstabs T2D by WH_Risk
/statistics CHISQ.

.